@@ -10,7 +10,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(match_array_or_regex match_regex_or_array);
 
-our $VERSION = '0.52'; # VERSION
+our $VERSION = '0.54'; # VERSION
 
 our %SPEC;
 
@@ -85,7 +85,7 @@ SHARYANTO::Array::Util - Array-related utilities
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -98,18 +98,44 @@ None are exported by default, but they are exportable.
 
 None are exported by default, but they are exportable.
 
-=head2 match_array_or_regex() -> any
+=head2 match_array_or_regex(%args) -> [status, msg, result, meta]
 
-No arguments.
+This routine can be used to match an item against a regex or a list of
+strings/regexes, e.g. when matching against an ACL.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<haystack>* => I<any>
+
+=item * B<needle>* => I<str>
+
+=back
 
 Return value:
 
-=head2 match_regex_or_array() -> any
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
 
-No arguments.
+=head2 match_regex_or_array(%args) -> [status, msg, result, meta]
+
+This routine can be used to match an item against a regex or a list of
+strings/regexes, e.g. when matching against an ACL.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<haystack>* => I<any>
+
+=item * B<needle>* => I<str>
+
+=back
 
 Return value:
 
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
