@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(has_circular_ref);
 
-our $VERSION = '0.52'; # VERSION
+our $VERSION = '0.54'; # VERSION
 
 our %SPEC;
 
@@ -71,7 +71,7 @@ SHARYANTO::Data::OldUtil - Data utilities
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -84,12 +84,22 @@ None are exported by default, but they are exportable.
 
 None are exported by default, but they are exportable.
 
-=head2 has_circular_ref() -> any
+=head2 has_circular_ref(%args) -> [status, msg, result, meta]
 
-No arguments.
+Does not deal with weak references.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<data>* => I<any>
+
+=back
 
 Return value:
 
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =head1 SEE ALSO
 
 L<Data::Structure::Util> has the XS/C version of C<has_circular_ref> which is 3
