@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(clone_circular_refs);
 
-our $VERSION = '0.52'; # VERSION
+our $VERSION = '0.54'; # VERSION
 
 our %SPEC;
 
@@ -102,7 +102,7 @@ SHARYANTO::Data::Util - Data utilities
 
 =head1 VERSION
 
-version 0.52
+version 0.54
 
 =head1 SYNOPSIS
 
@@ -115,12 +115,43 @@ None are exported by default, but they are exportable.
 
 None are exported by default, but they are exportable.
 
-=head2 clone_circular_refs() -> any
+=head2 clone_circular_refs(%args) -> [status, msg, result, meta]
 
-No arguments.
+For example, this data:
+
+    $x = [1];
+    $data = [$x, 2, $x];
+
+contains circular references by referring to C<$x> twice. After
+C<clone_circular_refs>, data will become:
+
+    $data = [$x, 2, [1]];
+
+that is, the subsequent circular references will be deep-copied. This makes it
+safe to transport to JSON, for example.
+
+Sometimes it doesn't work, for example:
+
+    $data = [1];
+    push @$data, $data;
+
+Cloning will still create circular references.
+
+This function modifies the data structure in-place, and return true for success
+and false upon failure.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<data>* => I<any>
+
+=back
 
 Return value:
 
+Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+
 =head1 SEE ALSO
 
 To check for circular references, try C<has_circular_ref> from
